.. _2015.8.5:

===========================
Salt 2015.8.5 Release Notes
===========================

.. admonition:: About this Release

    Salt 2015.8.5 is identical to the 2015.8.4 release with the addition of
    a fix for :issue:`30820`, fixed by **PR** `#30833`_. For convenience, the
    content from the 2015.8.4 release notes is included below.

.. _`#30833`: https://github.com/saltstack/salt/pull/30833

Known Issue in ``boto_*`` execution modules
===========================================

This release contains an issue that causes the ``boto_*`` execution modules to
display a ``__salt__ not defined`` error (:issue:`30300`). This issue will be
fixed in an upcoming release, but can be manually resolved by completing the
following:

1. Download the ``boto_*`` execution modules that you would like to update from
   the 2015.8 branch of Salt. A complete list of affected modules with the
   specific changes is available in **PR** `#30867`_.

   A simple way to get the updated modules is to `download
   <https://github.com/saltstack/salt/archive/2015.8.zip>`_ a zip file of the
   2015.8 branch from GitHub. The updated modules are in the ``salt\modules``
   directory.

2. Copy the ``boto_*`` modules to the ``\srv\salt\_modules`` directory on your
   Salt master.

3. Run the following command to sync these modules to all Salt minions:

   .. code-block:: bash

       salt '*' saltutil.sync_modules


.. _`#30867`: https://github.com/saltstack/salt/pull/30867/files

--------------------------

**2015.8.4 Release Notes**

.. include:: 2015.8.4.rst
   :start-line: 16
